@@ -22,12 +22,11 @@ __author__ = 'Giuseppe Sucameli'
 __date__ = 'April 2012'
 __copyright__ = '(C) 2012, Giuseppe Sucameli'
 # This will get replaced with a git SHA1 when you do a git archive
-__revision__ = 'f6ddc62fdb8ae589d3827e84d0c25bf669931040'
+__revision__ = '0c5774c0685d4b6f3e92a086234455708d1cd427'
 
 from qgis.PyQt.QtWidgets import QDialog, QMessageBox
 
 from .db_plugins.plugin import TableField
-
 from .ui.ui_DlgFieldProperties import Ui_DbManagerDlgFieldProperties as Ui_Dialog
 
 
@@ -42,7 +41,13 @@ class DlgFieldProperties(QDialog, Ui_Dialog):
 
         for item in self.db.connector.fieldTypes():
             self.cboType.addItem(item)
-        self.setField(self.fld)
+
+        supportCom = self.db.supportsComment()
+        if not supportCom:
+            self.label_6.setVisible(False)
+            self.editCom.setVisible(False)
+
+        self.setField(fld)
 
         self.buttonBox.accepted.connect(self.onOK)
 
@@ -56,6 +61,10 @@ class DlgFieldProperties(QDialog, Ui_Dialog):
         self.chkNull.setChecked(not fld.notNull)
         if fld.hasDefault:
             self.editDefault.setText(fld.default)
+        tab = self.table.name
+        field = fld.name
+        res = self.db.connector.getComment(tab, field)
+        self.editCom.setText(res) # Set comment value
 
     def getField(self, newCopy=False):
         fld = TableField(self.table) if not self.fld or newCopy else self.fld
@@ -64,6 +73,8 @@ class DlgFieldProperties(QDialog, Ui_Dialog):
         fld.notNull = not self.chkNull.isChecked()
         fld.default = self.editDefault.text()
         fld.hasDefault = fld.default != ""
+        # Get the comment from the LineEdit
+        fld.comment = self.editCom.text()
         try:
             modifier = int(self.editLength.text())
         except ValueError:
