@@ -1,4 +1,3 @@
-
 # -*- coding: utf-8 -*-
 
 """
@@ -24,7 +23,7 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = 'f6ddc62fdb8ae589d3827e84d0c25bf669931040'
+__revision__ = '0c5774c0685d4b6f3e92a086234455708d1cd427'
 
 import os
 
@@ -86,6 +85,7 @@ class rgb2pct(GdalAlgorithm):
         arguments.append(str(self.parameterAsInt(parameters, self.NCOLORS, context)))
 
         out = self.parameterAsOutputLayer(parameters, self.OUTPUT, context)
+        self.setOutputValue(self.OUTPUT, out)
         arguments.append('-of')
         arguments.append(QgsRasterFileWriter.driverForExtension(os.path.splitext(out)[1]))
         raster = self.parameterAsRasterLayer(parameters, self.INPUT, context)
@@ -96,9 +96,10 @@ class rgb2pct(GdalAlgorithm):
         arguments.append(out)
 
         if isWindows():
-            commands = ['cmd.exe', '/C ', self.commandName() + '.bat',
-                        GdalUtils.escapeAndJoin(arguments)]
+            commands = ["python3", "-m", self.commandName()]
         else:
-            commands = [self.commandName() + '.py', GdalUtils.escapeAndJoin(arguments)]
+            commands = [self.commandName() + '.py']
+
+        commands.append(GdalUtils.escapeAndJoin(arguments))
 
         return commands
